@@ -30,6 +30,7 @@
 #include <libxml/catalog.h>
 #include <libxml/tree.h>
 #include <libxml/xpathInternals.h>
+#include <libxml/globals.h>
 
 #include <glib/gstdio.h>
 
@@ -758,6 +759,7 @@ e_xml_find_children_nodes (xmlNode *parent,
 	xmlNode *node;
 	guint ii;
 
+	g_return_if_fail (parent != NULL);
 	g_return_if_fail (count > 0);
 
 	data = g_alloca (sizeof (struct _data) * count);
